#
# spec file for package python-Babel-doc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Babel-doc
Version:        2.8.0
Release:        3.3.1
Summary:        Internationalization utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://babel.pocoo.org/
Source:         https://files.pythonhosted.org/packages/source/B/Babel/Babel-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildArch:      noarch
%python_subpackages

%description
A collection of tools for internationalizing Python applications.

This package contains the documentation for Babel

%prep
%setup -q -n Babel-%{version}

%build
%{_python_use_flavor python3}
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
# Only building documentation

%files %{python_files}
%license LICENSE
%doc build/sphinx/html

%changelog
* Mon Jan 13 2020 mcalabkova@suse.com
- update to 2.8.0
  * CLDR: Upgrade to CLDR 36.0
  * Messages: Don't even open files with the "ignore" extraction method
  * Numbers: Fix formatting very small decimals when quantization is disabled
  * Messages: Attempt to sort all messages
  * Add years to changelog
  * Note that installation requires pytz
* Tue Jun  4 2019 pgajdos@suse.com
- version update to 2.7.0
  Possibly incompatible changes
  * General: Internal uses of ``babel.util.odict`` have been replaced with
    ``collections.OrderedDict`` from The Python standard library.
  Improvements
  * CLDR: Upgrade to CLDR 35.1 - Alberto Mardegan, Aarni Koskela (#626, #643)
  * General: allow anchoring path patterns to the start of a string -
    Brian Cappello (#600)
  * General: Bumped version requirement on pytz - @chrisbrake (#592)
  * Messages: `pybabel compile`: exit with code 1 if errors were encountered
  - Aarni Koskela (#647)
  * Messages: Add omit-header to update_catalog - Cédric Krier (#633)
  * Messages: Catalog update: keep user comments from destination by default
  - Aarni Koskela (#648)
  * Messages: Skip empty message when writing mo file - Cédric Krier (#564)
  * Messages: Small fixes to avoid crashes on badly formatted .po files
  - Bryn Truscott (#597)
  * Numbers: `parse_decimal()` `strict` argument and `suggestions`
  - Charly C (#590)
  * Numbers: don't repeat suggestions in parse_decimal strict - Serban
    Constantin (#599)
  * Numbers: implement currency formatting with long display names
  - Luke Plant (#585)
  * Numbers: parse_decimal(): assume spaces are equivalent to non-breaking
    spaces when not in strict mode - Aarni Koskela (#649)
  * Performance: Cache locale_identifiers() - Aarni Koskela (#644)
  Bugfixes
  * CLDR: Skip alt=... for week data (minDays, firstDay, weekendStart,
    weekendEnd) - Aarni Koskela (#634)
  * Dates: Fix wrong weeknumber for 31.12.2018 - BT-sschmid (#621)
  * Locale: Avoid KeyError trying to get data on WindowsXP - mondeja (#604)
  * Locale: get_display_name(): Don't attempt to concatenate variant
    information to None - Aarni Koskela (#645)
  * Messages: pofile: Add comparison operators to _NormalizedString - Aarni
    Koskela (#646)
  * Messages: pofile: don't crash when message.locations can't be sorted
  - Aarni Koskela (#646)
* Sun Jun 24 2018 arun@gmx.de
- update to version 2.6.0:
  * Possibly incompatible changes
    + Numbers: Refactor decimal handling code and allow bypass of
    decimal quantization. (@kdeldycke) (PR #538)
    + Messages: allow processing files that are in locales unknown to
    Babel (@akx) (PR #557)
    + General: Drop support for EOL Python 2.6 and 3.3 (@hugovk) (PR
    [#546])
  * Other changes
    + CLDR: Use CLDR 33 (@akx) (PR #581)
    + Lists: Add support for various list styles other than the
    default (@akx) (#552)
    + Messages: Add new PoFileError exception (@Bedrock02) (PR #532)
    + Times: Simplify Linux distro specific explicit timezone setting
    search (@scop) (PR #528)
  * Bugfixes
    + CLDR: avoid importing alt=narrow currency symbols (@akx) (PR
    [#558])
    + CLDR: ignore non-Latin numbering systems (@akx) (PR #579)
    + Docs: Fix improper example for date formatting (@PTrottier) (PR
    [#574])
    + Tooling: Fix some deprecation warnings (@akx) (PR #580)
  * Tooling & docs
    + Add explicit signatures to some date autofunctions (@xmo-odoo)
    (PR #554)
    + Include license file in the generated wheel package (@jdufresne)
    (PR #539)
    + Python 3.6 invalid escape sequence deprecation fixes (@scop) (PR
    [#528])
    + Test and document all supported Python versions (@jdufresne) (PR
    [#540])
    + Update copyright header years and authors file (@akx) (PR #559)
* Sun May  6 2018 arun@gmx.de
- update to version 2.5.3:
  * This is a maintenance release that reverts undesired API-breaking
    changes that slipped into 2.5.2 (see
    https://github.com/python-babel/babel/issues/550). It is based on
    v2.5.1 (f29eccd) with commits 7cedb84, 29da2d2 and edfb518
    cherry-picked on top.
- changes from version 2.5.2:
  * Bugfixes
    + Revert the unnecessary PyInstaller fixes from 2.5.0 and 2.5.1
    (#533) (@yagebu)
* Thu Oct  5 2017 arun@gmx.de
- update to version 2.5.1:
  * Use a fixed datetime to avoid test failures (#520)
    (@narendravardi)
  * Parse multi-line __future__ imports better (#519) (@akx)
  * Fix validate_currency docstring (#522)
  * Allow normalize_locale and exists to handle various unexpected
    inputs (#523) (@suhojm)
  * Make PyInstaller support more robust (#525, #526)
    (@thijstriemstra, @akx)
* Wed Aug 23 2017 tbechtold@suse.com
- update to 2.5.0:
  * Numbers: Add currency utilities and helpers (#491) (@kdeldycke)
  * Support PyInstaller (#500, #505) (@wodo)
  * Dates: Add __str__ to DateTimePattern (#515) (@sfermigier)
  * Dates: Fix an invalid string to bytes comparison when parsing TZ files on Py3 (#498) (@rowillia)
  * Dates: Formatting zero-padded components of dates is faster (#517) (@akx)
  * Documentation: Fix "Good Commits" link in CONTRIBUTING.md (#511) (@naryanacharya6)
  * Documentation: Fix link to Python gettext module (#512) (@Linkid)
  * Messages: Allow both dash and underscore separated locale identifiers in pofiles (#489, #490) (@akx)
  * Messages: Extract Python messages in nested gettext calls (#488) (@sublee)
  * Messages: Fix in-place editing of dir list while iterating (#476, #492) (@MarcDufresne)
  * Messages: Stabilize sort order (#482) (@xavfernandez)
  * Time zones: Honor the no-inherit marker for metazone names (#405) (@akx)
* Fri Mar 31 2017 aloisio@gmx.com
- Updated to 2.4.0
- Converted to single-spec
* Tue Jun 30 2015 aj@ajaissle.de
- Split documentation into separate package to avoid build loop
